@@ -1,5 +1,4 @@
-from finq.main import FINQ
-from test.test_foreach import collector
+from finq import FINQ
 
 
 def test_any():
