@@ -1,5 +1,4 @@
-from finq.main import FINQ
-from test.test_foreach import collector
+from finq import FINQ
 
 
 def test_count():
@@ -46,9 +45,10 @@ def test_max_diff():
 
     assert a_f.max_diff() == expected
 
+
 def test_max_diff_with_generator():
     expected = 25
 
     a_f = FINQ(i for i in [1, 2, 5, 7, 12, 15, 22, 26])
 
-    assert a_f.max_diff() == expected
\ No newline at end of file
+    assert a_f.max_diff() == expected
