@@ -1,4 +1,4 @@
-from finq.main import FINQ
+from finq import FINQ
 
 
 def test_sorts_ints():
